@@ -28,7 +28,9 @@ class TableAPI:
             count = c.fetchone()[0]
             if count < 5:
                 c.execute(f"CREATE TABLE IF NOT EXISTS {self.username}_{self.table_name} (key TEXT PRIMARY KEY, value TEXT)")
+                
                 connection.commit()
+                connection.close()
                 return jsonify(True)
             else:
                 return jsonify("You have reached the maximum number of allowed tables (5)")
@@ -41,6 +43,7 @@ class TableAPI:
         c = connection.cursor()
         c.execute(f"INSERT OR REPLACE INTO {self.username}_{self.table_name} (key, value) VALUES (?, ?)", (key, json.dumps(value)))
         connection.commit()
+        connection.close()
         return jsonify(True)
 
     def get(self,key):
@@ -49,11 +52,16 @@ class TableAPI:
             c = connection.cursor()
             c.execute(f"SELECT value FROM {self.username}_{self.table_name} WHERE key=?", (key,))
             result = c.fetchone()
+            connection.close()
             if result:
+                
                 return jsonify(json.loads(result[0]))
+                
             else:
+                
                 return jsonify(None)
         except sqlite3.OperationalError:
+            connection.close()
             return jsonify(None)
 
     def delete(self, key):
@@ -62,8 +70,10 @@ class TableAPI:
             c = connection.cursor()
             c.execute(f"DELETE FROM {self.username}_{self.table_name} WHERE key = ?", (key,))
             connection.commit()
+            connection.close()
             return jsonify(True)
         except sqlite3.OperationalError:
+            connection.close()
             return jsonify(False)
             
     def get_all(self):
@@ -72,6 +82,7 @@ class TableAPI:
             c = connection.cursor()
             c.execute(f"SELECT * FROM {self.username}_{self.table_name}")
             data = c.fetchall()
+            connection.close()
             if data:
                 result = []
                 for item in data:
@@ -85,10 +96,14 @@ class TableAPI:
                         result.append(f"- {key}\n ├ {value}\n └ Bool.\n")
                     else:
                         result.append(f"- {key}\n ├ {value}\n └ {type(value)}.\n")
+                    
                 return jsonify("".join(result))
+                
             else:
+                
                 return jsonify(None)
         except Exception as e:
+            connection.close()
             return jsonify(str(e))
     def tables(self):
         try:
@@ -96,11 +111,12 @@ class TableAPI:
             c = connection.cursor()
             c.execute(f"SELECT name FROM sqlite_master WHERE type='table' AND name LIKE '{self.username}_%'")
             tables = c.fetchall()
-            self.connection.close()
+            connection.close()
             prefix = len(f"{self.username}_")
             user_tables = [table[0][prefix:] for table in tables]
             return user_tables
         except sqlite3.OperationalError:
+            connection.close()
             return None    
     
 
@@ -110,6 +126,7 @@ class TableAPI:
             c = connection.cursor()
             c.execute(f"SELECT key FROM {self.username}_{self.table_name}")
             data = c.fetchall()
+            connection.close()
             if data:
                 keys = []
                 for item in data:
@@ -120,13 +137,17 @@ class TableAPI:
                     else:
                         keys.append(item[0])
                 if list:
+                    
                     return keys
                 else:
+                    
                     return jsonify("\n".join(keys))
                 
             else:
+                connection.close()
                 return jsonify(None)
         except Exception as e:
+            connection.close()
             return jsonify(str(e))
     
     def key_exists(self, key):
@@ -134,6 +155,9 @@ class TableAPI:
             c = connection.cursor()
             c.execute(f"SELECT 1 FROM {self.username}_{self.table_name} WHERE key=?", (key,))
             result = c.fetchone()
+        
+            connection.close()
+            
             if result:
                 return 1
             else:
@@ -145,6 +169,7 @@ class TableAPI:
             c = connection.cursor()
             c.execute(f"SELECT value FROM {self.username}_{self.table_name} WHERE key=?", (key,))
             data = c.fetchone()
+            connection.close()
             if data:
                 json_data = json.loads(data[0])
                 if isinstance(json_data, list):
@@ -157,6 +182,7 @@ class TableAPI:
             else:
                 return "Key does not exist"
         except Exception as e:
+            connection.close()
             return str(e)
     
     def unpush(self, key, value):
@@ -165,6 +191,7 @@ class TableAPI:
             c = connection.cursor()
             c.execute(f"SELECT value FROM {self.username}_{self.table_name} WHERE key=?", (key,))
             data = c.fetchone()
+            connection.close()
             if data:
                 json_data = json.loads(data[0])
                 if isinstance(json_data, list):
